==> AnnBuilder_1.3.3.tar.gz: AnnBuilder/man/GOXMLParser.Rd <==
\name{GOXMLParser}
\alias{GOXMLParser}
\alias{getChildNodes}
\alias{getOffspringNodes}
\alias{getParentNodes}
\alias{getAncestors}
\alias{getTopGOid}
\alias{mapGO2Category}
\alias{getGOGroupIDs}
\alias{mapGO2AllProbe}
\title{Functions to read/parse the XML document of Gene Ontology data}
\description{
  These functions are used by \code{\link{GO-class}} to read/parse the
  Gene Ontology data file (in XML formate) and figures out the
  parent-childe relations.
}
\usage{
GOXMLParser(fileName)
getChildNodes(goid, goData)
getOffspringNodes(goid, goData, keepTree = FALSE)
getParentNodes(goid, goData, sep = ";")
getAncestors(goid, goData, sep = ";", keepTree = FALSE, top = "GO:0003673")
getTopGOid(what = c("mf", "bp", "cc", "go"))
mapGO2Category(goData)
getGOGroupIDs(onto = FALSE)
mapGO2AllProbe(go2Probe, goData, goid = "", sep = ";", all = TRUE)
}

\arguments{
  \item{fileName}{\code{fileName} a character string for the name of the
    file of Gene  Ontology xml data that are stored locally}
  \item{goData}{\code{goData} a matrix with three columns for GO ids,
    parent GO ids, and the ontology terms}
  \item{goid}{\code{goid} a character string for the id of Gene Ontology
    term (e.g. GO:006742)}
  \item{keepTree}{\code{keepTree} a boolean indicating whether the tree
    structure showing parent-chiled relations will be preserved}
  \item{sep}{\code{sep} a character string for separater used to
    separate mulitple entries}
  \item{top}{\code{top} a character string for the GO id that is the
    root for all the other GO ids along parent-child relation tree}
  \item{what}{\code{what} a character string that has to be one of "mf",
    "bp", "cc", "go"}
  \item{onto}{\code{onto} a boolean that is set to TRUE if the GO id for
    the topmost node is to be returned or FALSE if the GO ids for the
    three categories (BP, MF, and CC) to be returned}
  \item{go2Probe}{\code{go2Probe} a matrix that maps GO ids to probe
    ids}
  \item{all}{\code{all} a boolean to indicate whether to map all the GO
    ids contained in goData to probe ids (TRUE) or just the GO ids
    specified by goid (FALSE)}
}
\details{
  The GO site provides an XML document for the molecular function,
 biological process, and cellular component of genes. The basic XML
 structure is something like:
 \code{
 <go:term>
   <go:accession>GO:000xxx</go:accession>
   <go:name>a string for the function, process, or component</go:name>
   <go:isa rdf:resource="http://www.geneontology.org/go#GO:000xxxx" />
   <go:part-of:resource="http://www.geneontology.org/go#GO:000xxxx" />
   .
   .
 </go:term>}

 The XML document read from Gene Ontology site does not differentiats
 among the molecular function,biological process, and cellular component
 of genes as a go:name tag is used for the function, process, and
 component of genes. To determine whether a go:name tag is for the
 function, process, or component of a given gene identified by a GO
 accession number, the go:isa or go:part-of tag that keep reference of
 the parent-children relationship have to be retained for later use to
 move up a tree to find the correct category. As the result, the matrix
 returned by \code{\link{GOXMLParser}} has three columns with one for
 the GOids, one for the GO ids of the direct parents (a ";" is used to
 separate multiple GO ids), and one for the ontology term defined.

 \code{\link{getChildNodes}} finds the direct children of a given GO id
 based on a matrix containing the parent-child relationships (e. g. the
 one returned by \code{\link{GOXMLParser}}). 

 \code{\link{getOffspringNodes}} finds all the direct or direct children
 of a given GO id based on a matrix containing the parent-child
 relationships (e. g. the one returned by \code{\link{GOXMLParser}})
   
 \code{\link{getParentNodes}} finds the direct parent of a given GO id
 based on a matrix containing the parent-child relationships (e. g. the
 one returned by \code{\link{GOXMLParser}}).

 \code{\link{getAncestors}} finds all the direct or direct parents
 of a given GO id based on a matrix containing the parent-child
 relationships (e. g. the one returned by \code{\link{GOXMLParser}})

 \code{\link{getTopGOid}} figures out the root GO id for "mf" - molecular
 funciton, "bp" - biological process, "cc" - celullar component,  and
 "go" - the whole Gene Ontology tree))

 \code{\link{mapGO2Category}} maps GO ids to the three categories (MF,
 BP, CC) they belong to. 

 \code{\link{getGOGroupIDs}} returns the GO id(s) for the topmost or the
 three nodes corresponding to the three categories (MF, BP, and CC).

 \code{\link{mapGO2AllProbe}} maps GO ids to probe ids that are related
 to the GO id and all its offsprings.
}
\value{
  \code{\link{GOXMLParser}} returns a matrix with three columns.

  \code{\link{getChildNodes}} returns a vector of character strings.

  \code{\link{getOffspringNodes}} returns a vector or list of vectors
  depending on wheter the tree structure of parent-childern will be
  preserved.

  \code{\link{getParentNodes}} returns a vector of character string.

  \code{\link{getAncestors}} returns a vector or list of vectors
  depending on wheter the tree structure of parent-childern will be
  preserved.

  \code{\link{mapGO2Category}} returns a matrix with two columns
  containing GO ids and letters representing one of the three categories
  (MF, BP, and CC).

  \code{\link{getGOGroupIDs}} returns a vector of string(s) for GO
  id(s).

  \code{\link{mapGO2AllProbe}} returns a matrix with GO ids as one
  column and mappings to probe ids related to the GO ids and all its
  offsprings as the other column.

  \code{\link{getTopGOid}} returns a character string for a GO id.
}
\references{\url{http://www.geneontology.org}}
\author{Jianhua (John) Zhang }
\note{This function is part of the Biocondutor project within a package at the
  Dana-Farber Cancer Institute to provide Bioinformatics functionalities
  through R}

\seealso{ \code{\link{GO-class}}}

\examples{

# Create the XML doc
  cat(paste("<?xml version='1.0'?>",
         "<!-- A test file for the examples in GOXMLParser.R Doc -->",
         "<go>",            
             "<go:term>",
                 "<go:accession>GO:0003674</go:accession>",
                 "<go:name>molecular_function</go:name>",
                 "<go:is_a rdf='http://wwww.myurl.org/go#GO:0003673' />",
                 "<go:part_of rdf = 'http://wwww.myurl.org/go#GO:0003672' />",
             "</go:term>",
             "<go:term>",
                 "<go:accession>GO:0005575</go:accession>",
                 "<go:name>cellular_cpmponent</go:name>",
                 "<go:is_a rdf= 'http://wwww.myurl.org/go#GO:0003673'/>",
                 "<go:part_of rdf = 'http://wwww.myurl.org/go#GO:0003674' />",
             "</go:term>",
          "</go>"), file = "testDoc")

  # Parse the dummy file using GOXMLParser 
  goData <- GOXMLParser("testDoc")
  # Get the child nodes for a GO id
  getChildNodes("GO:0003674", goData)
  getOffspringNodes("GO:0003673", goData, FALSE)
  getParentNodes("GO:0005575", goData)
  getAncestors("GO:0005575", goData, ";", FALSE, "GO:0003674")
  getTopGOid("GO")
  unlink("testDoc")
}

\keyword{manip}

==> AnnBuilder_1.4.2.tar.gz: AnnBuilder/man/GOXMLParser.Rd <==
\name{GOXMLParser}
\alias{GOXMLParser}
\alias{getChildNodes}
\alias{getOffspringNodes}
\alias{getParentNodes}
\alias{getAncestors}
\alias{getTopGOid}
\alias{mapGO2Category}
\alias{getGOGroupIDs}
\alias{mapGO2AllProbe}
\title{Functions to read/parse the XML document of Gene Ontology data}
\description{
  These functions are used by \code{\link{GO-class}} to read/parse the
  Gene Ontology data file (in XML formate) and figures out the
  parent-child relations.
}
\usage{
GOXMLParser(fileName)
getChildNodes(goid, goData)
getOffspringNodes(goid, goData, keepTree = FALSE)
getParentNodes(goid, goData, sep = ";")
getAncestors(goid, goData, sep = ";", keepTree = FALSE, top = "GO:0003673")
getTopGOid(what = c("MF", "BP", "CC", "GO"))
mapGO2Category(goData)
getGOGroupIDs(onto = FALSE)
mapGO2AllProbe(go2Probe, goData, goid = "", sep = ";", all = TRUE)
}

\arguments{
  \item{fileName}{\code{fileName} a character string for the name of the
    file of Gene  Ontology xml data that are stored locally}
  \item{goData}{\code{goData} a matrix with three columns for GO ids,
    parent GO ids, and the ontology terms}
  \item{goid}{\code{goid} a character string for the id of Gene Ontology
    term (e.g. GO:006742)}
  \item{keepTree}{\code{keepTree} a boolean indicating whether the tree
    structure showing parent-child relations will be preserved}
  \item{sep}{\code{sep} a character string for separator used to
    separate multiple entries}
  \item{top}{\code{top} a character string for the GO id that is the
    root for all the other GO ids along parent-child relation tree}
  \item{what}{\code{what} a character string that has to be one of "mf",
    "bp", "cc", "go"}
  \item{onto}{\code{onto} a boolean that is set to TRUE if the GO id for
    the topmost node is to be returned or FALSE if the GO ids for the
    three categories (BP, MF, and CC) to be returned}
  \item{go2Probe}{\code{go2Probe} a matrix that maps GO ids to probe
    ids}
  \item{all}{\code{all} a boolean to indicate whether to map all the GO
    ids contained in goData to probe ids (TRUE) or just the GO ids
    specified by goid (FALSE)}
}
\details{
  The GO site provides an XML document for the molecular function,
 biological process, and cellular component of genes. The basic XML
 structure is something like:
 \code{
 <go:term>
   <go:accession>GO:000xxx</go:accession>
   <go:name>a string for the function, process, or component</go:name>
   <go:isa rdf:resource="http://www.geneontology.org/go#GO:000xxxx" />
   <go:part-of:resource="http://www.geneontology.org/go#GO:000xxxx" />
   .
   .
 </go:term>}

 The XML document read from Gene Ontology site does not differentiate
 among the molecular function,biological process, and cellular component
 of genes as a go:name tag is used for the function, process, and
 component of genes. To determine whether a go:name tag is for the
 function, process, or component of a given gene identified by a GO
 accession number, the go:isa or go:part-of tag that keep reference of
 the parent-child relationship have to be retained for later use to
 move up a tree to find the correct category. As the result, the matrix
 returned by \code{\link{GOXMLParser}} has columns for
 the GOids, the GO ids of the direct parents (a ";" is used to
 separate multiple GO ids), and the ontology term defined, together with
 some columns for other data.

 \code{\link{getChildNodes}} finds the direct children of a given GO id
 based on a matrix containing the parent-child relationships (e. g. the
 one returned by \code{\link{GOXMLParser}}). 

 \code{\link{getOffspringNodes}} finds all the direct or direct children
 of a given GO id based on a matrix containing the parent-child
 relationships (e. g. the one returned by \code{\link{GOXMLParser}})
   
 \code{\link{getParentNodes}} finds the direct parent of a given GO id
 based on a matrix containing the parent-child relationships (e. g. the
 one returned by \code{\link{GOXMLParser}}).

 \code{\link{getAncestors}} finds all the direct or direct parents
 of a given GO id based on a matrix containing the parent-child
 relationships (e. g. the one returned by \code{\link{GOXMLParser}})

 \code{\link{getTopGOid}} figures out the root GO id for "mf" - molecular
 funciton, "bp" - biological process, "cc" - celullar component,  and
 "go" - the whole Gene Ontology tree))

 \code{\link{mapGO2Category}} maps GO ids to the three categories (MF,
 BP, CC) they belong to. 

 \code{\link{getGOGroupIDs}} returns the GO id(s) for the topmost or the
 three nodes corresponding to the three categories (MF, BP, and CC).

 \code{\link{mapGO2AllProbe}} maps GO ids to probe ids that are related
 to the GO id and all its offsprings.
}
\value{
  \code{\link{GOXMLParser}} returns a matrix.

  \code{\link{getChildNodes}} returns a vector of character strings.

  \code{\link{getOffspringNodes}} returns a vector or list of vectors
  depending on wheter the tree structure of parent-childern will be
  preserved.

  \code{\link{getParentNodes}} returns a vector of character string.

  \code{\link{getAncestors}} returns a vector or list of vectors
  depending on whether the tree structure of parent-childern will be
  preserved.

  \code{\link{mapGO2Category}} returns a matrix with two columns
  containing GO ids and letters representing one of the three categories
  (MF, BP, and CC).

  \code{\link{getGOGroupIDs}} returns a vector of string(s) for GO
  id(s).

  \code{\link{mapGO2AllProbe}} returns a matrix with GO ids as one
  column and mappings to probe ids related to the GO ids and all its
  offsprings as the other column.

  \code{\link{getTopGOid}} returns a character string for a GO id.
}
\references{\url{http://www.geneontology.org}}
\author{Jianhua (John) Zhang }
\note{This function is part of the Biocondutor project within a package at the
  Dana-Farber Cancer Institute to provide Bioinformatics functionalities
  through R}

\seealso{ \code{\link{GO-class}}}

\examples{

# Create the XML doc
  cat(paste("<?xml version='1.0'?>",
         "<!-- A test file for the examples in GOXMLParser.R Doc -->",
         "<go>",            
             "<go:term>",
                 "<go:accession>GO:0003674</go:accession>",
                 "<go:name>molecular_function</go:name>",
                 "<go:is_a rdf='http://wwww.myurl.org/go#GO:0003673' />",
                 "<go:part_of rdf = 'http://wwww.myurl.org/go#GO:0003672' />",
             "</go:term>",
             "<go:term>",
                 "<go:accession>GO:0005575</go:accession>",
                 "<go:name>cellular_cpmponent</go:name>",
                 "<go:is_a rdf= 'http://wwww.myurl.org/go#GO:0003673'/>",
                 "<go:part_of rdf = 'http://wwww.myurl.org/go#GO:0003674' />",
             "</go:term>",
          "</go>"), file = "testDoc")

  # Parse the dummy file using GOXMLParser 
  goData <- GOXMLParser("testDoc")
  # Get the child nodes for a GO id
  getChildNodes("GO:0003674", goData)
  getOffspringNodes("GO:0003673", goData, FALSE)
  getParentNodes("GO:0005575", goData)
  getAncestors("GO:0005575", goData, ";", FALSE, "GO:0003674")
  getTopGOid("GO")
  unlink("testDoc")
}

\keyword{manip}
